Learn R Programming

lda.svi (version 0.1.0)

lda.svi-package: lda.svi: Fit Latent Dirichlet Allocation Models using Stochastic Variational Inference

Description

Fits Latent Dirichlet Allocation topic models to text data using the stochastic variational inference algorithm described in Hoffman et. al. (2013) <arXiv:1206.7051v3>. This method is more efficient than the original batch variational inference algorithm for LDA, and allows users to fit LDA models with more topics and to larger text corpora than would be feasible using that older method.

Arguments

See Also

Useful links: